package com.leromro.core.domain;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;

import java.math.BigDecimal;
import java.time.LocalDateTime;
import java.io.Serializable;

import com.leromro.common.annotation.Excel;
import com.leromro.common.annotation.Sensitive;
import com.leromro.common.core.domain.BaseEntity;
import com.leromro.common.enums.DesensitizedType;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import lombok.experimental.Accessors;

/**
 * <p>
 * 志愿者信息表
 * </p>
 *
 * @author lr
 * @since 2025-04-07
 */
@Data
@AllArgsConstructor
@NoArgsConstructor
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
@TableName("l_volunteer_info")
@ApiModel(value="VolunteerInfo", description="志愿者信息表")
public class VolunteerInfo extends BaseEntity {

    private static final long serialVersionUID = 1L;

    @ApiModelProperty(value = "主键id")
    @TableId(value = "volunteer_info_id", type = IdType.AUTO)
    private Long volunteerInfoId;

    @ApiModelProperty(value = "用户id")
    private Long volunteerId;

    @ApiModelProperty(value = "志愿者姓名")
    private String name;

//    @Sensitive(desensitizedType = DesensitizedType.ID_CARD)
    @ApiModelProperty(value = "身份证号")
    private String idCard;

    @ApiModelProperty(value = "照片")
    private String idCardPicture;

    @ApiModelProperty(value = "评分")
    private Double score;

    @ApiModelProperty(value = "大类别")
    private Long serviceCategory;


    @ApiModelProperty(value = "技能描述")
    private String skillDescribe;

//    @Sensitive(desensitizedType = DesensitizedType.PHONE)
    @ApiModelProperty(value = "联系电话")
    private String phonenumber;

    @ApiModelProperty(value = "性别 0女 1男")
    private Integer sex;

    @ApiModelProperty(value = "年龄")
    private Integer age;

    @ApiModelProperty(value = "状态 0 不接单  1 正在接单")
    private Integer status;

    @ApiModelProperty(value = "证书图片")
    private String certificationPicture;

    @ApiModelProperty(value = "志愿者照片")
    private String volunteerPicture;


    @ApiModelProperty(value = "地区")
    private String city;

    @ApiModelProperty(value = "详细地址")
    private String address;

    @ApiModelProperty(value = "业务id")
    private Long businessManagementId;

    @ApiModelProperty(value = "审批状态 1待审批2已通过3已驳回")
    private String appStatus;

    @ApiModelProperty(value = "驳回原因")
    private String rejectReason;

    @TableField("project_name")
    @ApiModelProperty("服务项目名称")
    private String projectName;

    @TableField("project_type_name")
    @ApiModelProperty("项目类别名称")
    private String  projectTypeName;

    @ApiModelProperty("科目名称")
    private String serviceSubjectName;

    @ApiModelProperty("业务层级名称")
    private String businessTierName;

    @ApiModelProperty("业务价格")
    private BigDecimal businessPrice;

    @ApiModelProperty("业务时长(整数分钟)")
    private Integer businessDuration;

    @TableField("province_code")
    @ApiModelProperty("省级区划编号")
    private String provinceCode;

    @TableField("province_name")
    @ApiModelProperty("省级名称")
    private String provinceName;

    @TableField("city_code")
    @ApiModelProperty("市级编号")
    private String cityCode;

    @TableField("city_name")
    @ApiModelProperty("市级名称")
    private String cityName;

    @TableField("district_code")
    @ApiModelProperty("区级区划编号")
    private String districtCode;

    @TableField("district_name")
    @ApiModelProperty("区级名称")
    private String districtName;
}
